@@ -1,4 +1,5 @@
 import json
+import os
 import traceback
 from functools import wraps
 from sys import stderr
@@ -100,11 +101,14 @@ def create_service(app: str, override=None, providers=None):
     def route(path, *, streaming=False):
         def decorator(func):
             @wraps(func)
-            def wrapped(*, noreply=False, timeout=1, retries=0, **kwargs):
+            def wrapped(*, noreply=False, timeout=1, retries=0, local=False, **kwargs):
                 assert (
                     not noreply or not retries
                 ), "Cannot retry a noreply request, use streaming instead"
 
+                if local:
+                    return wrapped.local(**kwargs)
+
                 if providers:
                     endpoints = [f"{provider}{path}" for provider in providers]
                 else:
@@ -156,6 +160,7 @@ def create_service(app: str, override=None, providers=None):
                             return "", 500
 
                     app.add_url_rule(path, func.__name__, handler, methods=["POST"])
+                    wrapped.local = func
                     return func
 
                 return decorator
@@ -212,6 +217,8 @@ def requires_master_secret(func):
 def requires_access_token(func):
     @wraps(func)
     def wrapped(**kwargs):
+        if os.getenv("ENV") == "prod":
+            return func(**kwargs, master_secret=get_master_secret())
         try:
             return func(**kwargs, access_token=get_token())
         except PermissionError:
